==> ccscript-1.7.0.tar.gz: ccscript-1.7.0/src/module.cpp <==
// Copyright (C) 1999-2001 Open Source Telecom Corporation.
//  
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software 
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
// 
// As a special exception to the GNU General Public License, permission is 
// granted for additional uses of the text contained in its release 
// of ccscript.
// 
// The exception is that, if you link the ccscript library with other
// files to produce an executable, this does not by itself cause the
// resulting executable to be covered by the GNU General Public License.
// Your use of that executable is in no way restricted on account of
// linking the ccscript library code into it.
// 
// This exception does not however invalidate any other reasons why
// the executable file might be covered by the GNU General Public License.
// 
// This exception applies only to the code released under the 
// name ccscript.  If you copy code from other releases into a copy of
// ccscript, as the General Public License permits, the exception does
// not apply to the code that you add in this way.  To avoid misleading
// anyone as to the status of such modified files, you must delete
// this exception notice from them.
// 
// If you write modifications of your own for ccscript, it is your choice
// whether to permit this exception to apply to your modifications.
// If you do not wish that, delete this exception notice.  

#include <cc++/config.h>
#include <cc++/macros.h>
#include <cc++/misc.h>
#include <cc++/slog.h>
#include "script.h"

ScriptPackage *ScriptPackage::first = NULL;
ScriptModule *ScriptModule::first = NULL;
ScriptProperty *ScriptProperty::first = NULL;

ScriptProperty::ScriptProperty(const char *name)
{
	id = name;
	next = first;
	first = this;
}

ScriptProperty *ScriptProperty::find(const char *name)
{
	ScriptProperty *prop = first;

	while(prop)
	{
		if(!stricmp(prop->id, name))
			break;
		prop = prop->next;
	}
	return prop;
}
	
ScriptModule::ScriptModule(const char *name)
{
	next = first;
	first = this;
	cmd = name;
}

ScriptModule *ScriptModule::find(const char *name)
{
	ScriptModule *mod = first;
	char keybuf[33];
	int len = 0;

	while(*name && *name != '.' && len < sizeof(keybuf) - 1)
		keybuf[len++] = *(name++);

	while(mod)
	{
		if(!stricmp(keybuf, mod->cmd))
			return mod;
		mod = mod->next;
	}
	return mod;
}

ScriptSession::ScriptSession(ScriptInterp *i)
{
	interp = i;
}

void ScriptSession::sleepScheduler(timeout_t timeout)
{
	interp->sleepScheduler(timeout);
}

void ScriptSession::stepScheduler(const char *event)
{
	interp->stepScheduler(event);
}

ScriptPackage::ScriptPackage(char *name) :
DSO(name)
{
	filename = new char[strlen(name) + 1];
	strcpy(filename, name);
	next = first;
	first = this;
}

bool ScriptPackage::usePackage(const char *name)
{
	ScriptPackage *pkg = first;
	char buffer[256];

	if(*name != '.' && *name != '/')
	{
		snprintf(buffer, sizeof(buffer), "%s/%s.pkg",  SCRIPT_MODULE_PATH,  name);
		name = buffer;
	}

	while(pkg)
	{
		if(!strcmp(pkg->filename, name))
			return true;
		pkg = pkg->next;
	}

	if(!canAccess(name))
	{
		slog(SLOG_ERROR) << "use: cannot find " << name << endl;
		return false;
	}

	try
	{
		new ScriptPackage((char *)name);
	}
	catch (DSO *dso)
	{
		slog(SLOG_ERROR) << "use: cannot load " << name << endl;
		delete dso;
		return false;
	}
	return true;
}

==> ccscript-1.8.0.tar.gz: ccscript-1.8.0/src/module.cpp <==
// Copyright (C) 1999-2001 Open Source Telecom Corporation.
//  
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software 
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
// 
// As a special exception to the GNU General Public License, permission is 
// granted for additional uses of the text contained in its release 
// of ccscript.
// 
// The exception is that, if you link the ccscript library with other
// files to produce an executable, this does not by itself cause the
// resulting executable to be covered by the GNU General Public License.
// Your use of that executable is in no way restricted on account of
// linking the ccscript library code into it.
// 
// This exception does not however invalidate any other reasons why
// the executable file might be covered by the GNU General Public License.
// 
// This exception applies only to the code released under the 
// name ccscript.  If you copy code from other releases into a copy of
// ccscript, as the General Public License permits, the exception does
// not apply to the code that you add in this way.  To avoid misleading
// anyone as to the status of such modified files, you must delete
// this exception notice from them.
// 
// If you write modifications of your own for ccscript, it is your choice
// whether to permit this exception to apply to your modifications.
// If you do not wish that, delete this exception notice.  

#include <cc++/config.h>
#include <cc++/misc.h>
#include <cc++/slog.h>
#include <cc++/export.h>
#include "script.h"

#ifdef	__NAMESPACES__
namespace ost {
#endif

ScriptPackage *ScriptPackage::first = NULL;
ScriptModule *ScriptModule::first = NULL;
ScriptProperty *ScriptProperty::first = NULL;

ScriptProperty::ScriptProperty(const char *name)
{
	id = name;
	next = first;
	first = this;
}

ScriptProperty *ScriptProperty::find(const char *name)
{
	ScriptProperty *prop = first;

	while(prop)
	{
		if(!stricmp(prop->id, name))
			break;
		prop = prop->next;
	}
	return prop;
}
	
ScriptModule::ScriptModule(const char *name)
{
	next = first;
	first = this;
	cmd = name;
}

ScriptModule *ScriptModule::find(const char *name)
{
	ScriptModule *mod = first;
	char keybuf[33];
	int len = 0;

	while(*name && *name != '.' && len < sizeof(keybuf) - 1)
		keybuf[len++] = *(name++);

	while(mod)
	{
		if(!stricmp(keybuf, mod->cmd))
			return mod;
		mod = mod->next;
	}
	return mod;
}

ScriptSession::ScriptSession(ScriptInterp *i)
{
	interp = i;
}

void ScriptSession::sleepScheduler(timeout_t timeout)
{
	interp->sleepScheduler(timeout);
}

void ScriptSession::stepScheduler(const char *event)
{
	interp->stepScheduler(event);
}

ScriptPackage::ScriptPackage(char *name) :
DSO(name)
{
	filename = new char[strlen(name) + 1];
	strcpy(filename, name);
	next = first;
	first = this;
}

bool ScriptPackage::usePackage(const char *name)
{
	ScriptPackage *pkg = first;
	char buffer[256];

	if(*name != '.' && *name != '/')
	{
		snprintf(buffer, sizeof(buffer), "%s/%s.pkg",  SCRIPT_MODULE_PATH,  name);
		name = buffer;
	}

	while(pkg)
	{
		if(!strcmp(pkg->filename, name))
			return true;
		pkg = pkg->next;
	}

	if(!canAccess(name))
	{
		slog(SLOG_ERROR) << "use: cannot find " << name << endl;
		return false;
	}

	try
	{
		new ScriptPackage((char *)name);
	}
	catch (DSO *dso)
	{
		slog(SLOG_ERROR) << "use: cannot load " << name << endl;
		delete dso;
		return false;
	}
	return true;
}

#ifdef	__NAMESPACES__
};
#endif
